@@ -21,7 +21,7 @@ use Scalar::Util ();		# Core since 5.7.3
 use Storable ();		# Core since 5.7.3
 use Test::Builder ();		# Core since 5.6.2
 
-our $VERSION = '0.000_903';
+our $VERSION = '0.000_904';
 
 use constant ON_DARWIN		=> 'darwin' eq $^O;
 use constant ON_VMS		=> 'VMS' eq $^O;
@@ -495,9 +495,15 @@ sub _handle_pod {
 	# Before 3.24, Pod::Simple was too restrictive in parsing 'man'
 	# links, and they end up here. The regex is verbatim from
 	# Pod::Simple 3.24.
-	NEED_MAN_FIX
-	    and $section =~ m{^[^/|]+[(][-a-zA-Z0-9]+[)]$}s
-	    and goto &_handle_man;
+	if ( NEED_MAN_FIX && $section =~ m{^[^/|]+[(][-a-zA-Z0-9]+[)]$}s ) {
+	    # The misparse left the actual link text in {section}, but
+	    # an honest-to-God Pod link has it in {to}.
+	    $link->[1]{to} = delete $link->[1]{section};
+	    # While we're at it, we might as well make it an actual
+	    # 'man' link.
+	    $link->[1]{type} = 'man';
+	    goto &_handle_man;
+	}
 
 	return $self->_fail( $link, 'links to unknown section' );
 
@@ -748,9 +754,11 @@ sub _handle_url {
     }
 }
 
+# Returns true if the link refers to a man page, false (but defined) if
+# it does not, and undef if it could not be checked.
 sub _is_man_page {
     my ( $self, $link ) = @_;
-    $self->{man}
+    $self->man()
 	or return;
     $link->[1]{to}
 	or return;
@@ -762,7 +770,7 @@ sub _is_man_page {
 	$page,
     );
     return $self->{_cache}{man}{"@pg"} ||= IPC::Cmd::run( COMMAND => [
-	    qw{ man -w }, @pg ] );
+	    qw{ man -w }, @pg ] ) || 0;
 }
 
 sub _is_perl_file {
@@ -890,6 +898,8 @@ sub __token_end {
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Test::Pod::LinkCheck::Lite - Test POD links
@@ -908,13 +918,19 @@ Test::Pod::LinkCheck::Lite - Test POD links
 
 This Perl module tests POD links. A given file generates one failure for
 each broken link found. If no broken links are found, one passing test
-is generated. This all means that you can not know how many tests will
-be generated, and you will need to use L<Test::More|Test::More>'s
-C<done_testing()> at the end of your test.
+is generated. This all means that there is no way to know how many tests
+will be generated, and you will need to use L<Test::More|Test::More>'s
+C<done_testing()> (or something equivalent) at the end of your test.
+
+By its nature this module should be used only for author testing. The
+problem with using it in an installation test is that the validity of
+links external to the distribution being tested varies with things like
+operating system type and version, Perl version, installed Perl modules
+and their versions, and the Internet at large. I<Caveat user.>
 
 This module should probably be considered alpha-quality code at this
-point. It correctly checks most of my modest corpus, but beyond that
-deponent sayeth not.
+point. It checks most of my modest corpus (correctly, I hope), but
+beyond that deponent sayeth not.
 
 This module started its life as a low-dependency version of
 L<Test::Pod::LinkCheck|Test::Pod::LinkCheck>. Significant
@@ -1222,15 +1238,32 @@ This method returns the value of the C<'require_installed'> attribute.
 
 =head1 SEE ALSO
 
-L<Test::Pod::LinkCheck|Test::Pod::LinkCheck> by Apocalypse checks all
-POD links except for URLs. It is L<Moose|Moose>-based.
+L<Test::Pod::LinkCheck|Test::Pod::LinkCheck> by Apocalypse (C<APOCAL>)
+checks all POD links except for URLs. It is L<Moose|Moose>-based.
 
-L<Test::Pod::Links|Test::Pod::Links> by Sven Kirmess checks all URLs or
-URL-like things in the document, whether or not they are actual POD
-links.
+L<Test::Pod::Links|Test::Pod::Links> by Sven Kirmess (C<SKIRMESS>)
+checks all URLs or URL-like things in the document, whether or not they
+are actual POD links.
 
-L<Test::Pod::No404s|Test::Pod::No404s> by Apocalypse checks URL POD
-links.
+L<Test::Pod::No404s|Test::Pod::No404s> by Apocalypse (C<APOCAL>) checks
+URL POD links.
+
+=head1 ACKNOWLEDGMENTS
+
+The author would like to acknowledge the following, without whom this
+module would not exist -- at least, not in anything like its current
+form.
+
+Mohammed Anwar (C<MANWAR>) who submitted the "broken POD link" ticket
+that started me thinking about testing for this kind of thing.
+
+The CPAN Testers who, by testing my code under such a broad range of
+configurations, gave me an opportunity to make this module much more
+robust than it would otherwise have been. It is probably unfair to
+single out individual testers, but as the luck of the testing cycle
+would have it, results from Andreas J. König (C<ANDK>), Slaven Rezić
+(C<SREZIC>), and Chris Williams (C<BINGOS>) were particularly useful to
+me.
 
 =head1 SUPPORT
 
